.. currentmodule:: cotede

#############
API reference
#############

The public API resources are listed below.
All the rest of CoTeDe is considered support infrastructure and there is no reason to use or access explicitly what is not shown here.
I do intend to expand these resources in the near future, but this is what is available now.

Top-level resources
===================

.. autosummary::
   :toctree: generated/

   ProfileQC

Utils
=====

.. autosummary::
   :toctree: generated/

   utils.cotederc
   utils.list_cfgs
   utils.load_cfg
